Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterArchiveServiceServer(s grpc.ServiceRegistrar, srv ArchiveServiceServer)
- type ArchivePullRequest
- func (*ArchivePullRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ArchivePullRequest) GetDigest() string
- func (x *ArchivePullRequest) GetNamespace() string
- func (*ArchivePullRequest) ProtoMessage()
- func (x *ArchivePullRequest) ProtoReflect() protoreflect.Message
- func (x *ArchivePullRequest) Reset()
- func (x *ArchivePullRequest) String() string
- type ArchivePullResponse
- func (*ArchivePullResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ArchivePullResponse) GetData() []byte
- func (*ArchivePullResponse) ProtoMessage()
- func (x *ArchivePullResponse) ProtoReflect() protoreflect.Message
- func (x *ArchivePullResponse) Reset()
- func (x *ArchivePullResponse) String() string
- type ArchivePushRequest
- func (*ArchivePushRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ArchivePushRequest) GetData() []byte
- func (x *ArchivePushRequest) GetDigest() string
- func (x *ArchivePushRequest) GetNamespace() string
- func (*ArchivePushRequest) ProtoMessage()
- func (x *ArchivePushRequest) ProtoReflect() protoreflect.Message
- func (x *ArchivePushRequest) Reset()
- func (x *ArchivePushRequest) String() string
- type ArchiveResponse
- type ArchiveServiceClient
- type ArchiveServiceServer
- type ArchiveService_PullClient
- type ArchiveService_PullServer
- type ArchiveService_PushClient
- type ArchiveService_PushServer
- type UnimplementedArchiveServiceServer
- func (UnimplementedArchiveServiceServer) Check(context.Context, *ArchivePullRequest) (*ArchiveResponse, error)
- func (UnimplementedArchiveServiceServer) Pull(*ArchivePullRequest, grpc.ServerStreamingServer[ArchivePullResponse]) error
- func (UnimplementedArchiveServiceServer) Push(grpc.ClientStreamingServer[ArchivePushRequest, ArchiveResponse]) error
- type UnsafeArchiveServiceServer
Constants ¶
const ( ArchiveService_Check_FullMethodName = "/vorpal.archive.ArchiveService/Check" ArchiveService_Pull_FullMethodName = "/vorpal.archive.ArchiveService/Pull" ArchiveService_Push_FullMethodName = "/vorpal.archive.ArchiveService/Push" )
Variables ¶
var ArchiveService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "vorpal.archive.ArchiveService", HandlerType: (*ArchiveServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Check", Handler: _ArchiveService_Check_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "Pull", Handler: _ArchiveService_Pull_Handler, ServerStreams: true, }, { StreamName: "Push", Handler: _ArchiveService_Push_Handler, ClientStreams: true, }, }, Metadata: "archive/archive.proto", }
ArchiveService_ServiceDesc is the grpc.ServiceDesc for ArchiveService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_archive_archive_proto protoreflect.FileDescriptor
Functions ¶
func RegisterArchiveServiceServer ¶
func RegisterArchiveServiceServer(s grpc.ServiceRegistrar, srv ArchiveServiceServer)
Types ¶
type ArchivePullRequest ¶
type ArchivePullRequest struct {
Digest string `protobuf:"bytes,1,opt,name=digest,proto3" json:"digest,omitempty"`
Namespace string `protobuf:"bytes,2,opt,name=namespace,proto3" json:"namespace,omitempty"`
// contains filtered or unexported fields
}
func (*ArchivePullRequest) Descriptor
deprecated
func (*ArchivePullRequest) Descriptor() ([]byte, []int)
Deprecated: Use ArchivePullRequest.ProtoReflect.Descriptor instead.
func (*ArchivePullRequest) GetDigest ¶
func (x *ArchivePullRequest) GetDigest() string
func (*ArchivePullRequest) GetNamespace ¶
func (x *ArchivePullRequest) GetNamespace() string
func (*ArchivePullRequest) ProtoMessage ¶
func (*ArchivePullRequest) ProtoMessage()
func (*ArchivePullRequest) ProtoReflect ¶
func (x *ArchivePullRequest) ProtoReflect() protoreflect.Message
func (*ArchivePullRequest) Reset ¶
func (x *ArchivePullRequest) Reset()
func (*ArchivePullRequest) String ¶
func (x *ArchivePullRequest) String() string
type ArchivePullResponse ¶
type ArchivePullResponse struct {
Data []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
func (*ArchivePullResponse) Descriptor
deprecated
func (*ArchivePullResponse) Descriptor() ([]byte, []int)
Deprecated: Use ArchivePullResponse.ProtoReflect.Descriptor instead.
func (*ArchivePullResponse) GetData ¶
func (x *ArchivePullResponse) GetData() []byte
func (*ArchivePullResponse) ProtoMessage ¶
func (*ArchivePullResponse) ProtoMessage()
func (*ArchivePullResponse) ProtoReflect ¶
func (x *ArchivePullResponse) ProtoReflect() protoreflect.Message
func (*ArchivePullResponse) Reset ¶
func (x *ArchivePullResponse) Reset()
func (*ArchivePullResponse) String ¶
func (x *ArchivePullResponse) String() string
type ArchivePushRequest ¶
type ArchivePushRequest struct {
Data []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
Digest string `protobuf:"bytes,2,opt,name=digest,proto3" json:"digest,omitempty"`
Namespace string `protobuf:"bytes,3,opt,name=namespace,proto3" json:"namespace,omitempty"`
// contains filtered or unexported fields
}
func (*ArchivePushRequest) Descriptor
deprecated
func (*ArchivePushRequest) Descriptor() ([]byte, []int)
Deprecated: Use ArchivePushRequest.ProtoReflect.Descriptor instead.
func (*ArchivePushRequest) GetData ¶
func (x *ArchivePushRequest) GetData() []byte
func (*ArchivePushRequest) GetDigest ¶
func (x *ArchivePushRequest) GetDigest() string
func (*ArchivePushRequest) GetNamespace ¶
func (x *ArchivePushRequest) GetNamespace() string
func (*ArchivePushRequest) ProtoMessage ¶
func (*ArchivePushRequest) ProtoMessage()
func (*ArchivePushRequest) ProtoReflect ¶
func (x *ArchivePushRequest) ProtoReflect() protoreflect.Message
func (*ArchivePushRequest) Reset ¶
func (x *ArchivePushRequest) Reset()
func (*ArchivePushRequest) String ¶
func (x *ArchivePushRequest) String() string
type ArchiveResponse ¶
type ArchiveResponse struct {
// contains filtered or unexported fields
}
func (*ArchiveResponse) Descriptor
deprecated
func (*ArchiveResponse) Descriptor() ([]byte, []int)
Deprecated: Use ArchiveResponse.ProtoReflect.Descriptor instead.
func (*ArchiveResponse) ProtoMessage ¶
func (*ArchiveResponse) ProtoMessage()
func (*ArchiveResponse) ProtoReflect ¶
func (x *ArchiveResponse) ProtoReflect() protoreflect.Message
func (*ArchiveResponse) Reset ¶
func (x *ArchiveResponse) Reset()
func (*ArchiveResponse) String ¶
func (x *ArchiveResponse) String() string
type ArchiveServiceClient ¶
type ArchiveServiceClient interface {
Check(ctx context.Context, in *ArchivePullRequest, opts ...grpc.CallOption) (*ArchiveResponse, error)
Pull(ctx context.Context, in *ArchivePullRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[ArchivePullResponse], error)
Push(ctx context.Context, opts ...grpc.CallOption) (grpc.ClientStreamingClient[ArchivePushRequest, ArchiveResponse], error)
}
ArchiveServiceClient is the client API for ArchiveService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewArchiveServiceClient ¶
func NewArchiveServiceClient(cc grpc.ClientConnInterface) ArchiveServiceClient
type ArchiveServiceServer ¶
type ArchiveServiceServer interface {
Check(context.Context, *ArchivePullRequest) (*ArchiveResponse, error)
Pull(*ArchivePullRequest, grpc.ServerStreamingServer[ArchivePullResponse]) error
Push(grpc.ClientStreamingServer[ArchivePushRequest, ArchiveResponse]) error
// contains filtered or unexported methods
}
ArchiveServiceServer is the server API for ArchiveService service. All implementations must embed UnimplementedArchiveServiceServer for forward compatibility.
type ArchiveService_PullClient ¶
type ArchiveService_PullClient = grpc.ServerStreamingClient[ArchivePullResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ArchiveService_PullServer ¶
type ArchiveService_PullServer = grpc.ServerStreamingServer[ArchivePullResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ArchiveService_PushClient ¶
type ArchiveService_PushClient = grpc.ClientStreamingClient[ArchivePushRequest, ArchiveResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ArchiveService_PushServer ¶
type ArchiveService_PushServer = grpc.ClientStreamingServer[ArchivePushRequest, ArchiveResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedArchiveServiceServer ¶
type UnimplementedArchiveServiceServer struct{}
UnimplementedArchiveServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedArchiveServiceServer) Check ¶
func (UnimplementedArchiveServiceServer) Check(context.Context, *ArchivePullRequest) (*ArchiveResponse, error)
type UnsafeArchiveServiceServer ¶
type UnsafeArchiveServiceServer interface {
// contains filtered or unexported methods
}
UnsafeArchiveServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ArchiveServiceServer will result in compilation errors.